Crate scs_sdk_sys

Crate scs_sdk_sys 

Re-exports

pub use constants::*;
pub use input::*;
pub use telemetry::*;
pub use value::*;

Modules

channels
Raw channel names from the SCS Telemetry SDK headers.
configuration
Raw configuration identifiers and attribute names from the SCS Telemetry SDK.
constants
gameplay
Raw gameplay event and attribute names from the SCS Telemetry SDK.
games
Game identifiers and telemetry game-version constants.
input
Raw ABI declarations for the SCS Input SDK 1.00 interface.
telemetry
value