pub type ScsInputActiveCallback = unsafe extern "system" fn(active: ScsU8, context: ScsContext);Expand description
Callback used by SCS to notify a device that it became active or inactive.
pub type ScsInputActiveCallback = unsafe extern "system" fn(active: ScsU8, context: ScsContext);Callback used by SCS to notify a device that it became active or inactive.